#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class SimulationSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         SimulationSettingAtt
                | 
                | Interface to handle parameters of DELMIA Simulation Tools Options Tab page
                | Role: This interface is implemented by a component which represents the
                | controller of Simulation Tools Options parameter settings.
                | 
                |     Methods to set value of each parameter
                |     Methods to get value of each parameter
                |     Methods to get information on each parameter
                |     Methods to lock/unlock value of each parameter
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.simulation_setting_att = com_object

    def get_as_navigation_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetASNavigationModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ASNavigationMode
                |     parameter.
                |     Role:Retrieves the state of the ASNavigationMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetASNavigationModeInfo(io_admin_level, io_locked)

    def get_as_step_size_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetASStepSizeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ASStepSize
                |     parameter.
                |     Role:Retrieves the state of the ASStepSize parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetASStepSizeInfo(io_admin_level, io_locked)

    def get_ath_annotation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAthAnnotationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AthAnnotation
                |     parameter.
                |     Role:Retrieves the state of the AthAnnotation parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetAthAnnotationInfo(io_admin_level, io_locked)

    def get_ath_disable_sim_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAthDisableSimInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AthDisableSim
                |     parameter.
                |     Role:Retrieves the state of the AthDisableSim parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetAthDisableSimInfo(io_admin_level, io_locked)

    def get_ath_end_condition_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAthEndConditionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AthEndCondition
                |     parameter.
                |     Role:Retrieves the state of the AthEndCondition parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetAthEndConditionInfo(io_admin_level, io_locked)

    def get_ath_hyperlink_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAthHyperlinkInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AthHyperlink
                |     parameter.
                |     Role:Retrieves the state of the AthHyperlink parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetAthHyperlinkInfo(io_admin_level, io_locked)

    def get_ath_sel_agent_dlg_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAthSelAgentDlgInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AthSelAgentDlg
                |     parameter.
                |     Role:Retrieves the state of the AthSelAgentDlg parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetAthSelAgentDlgInfo(io_admin_level, io_locked)

    def get_ath_state_mgt_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAthStateMgtInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AthStateMgt
                |     parameter.
                |     Role:Retrieves the state of the AthStateMgt parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetAthStateMgtInfo(io_admin_level, io_locked)

    def get_ath_text_msg_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAthTextMsgInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AthTextMsg
                |     parameter.
                |     Role:Retrieves the state of the AthTextMsg parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetAthTextMsgInfo(io_admin_level, io_locked)

    def get_ath_viewpoint_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAthViewpointInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AthViewpoint
                |     parameter.
                |     Role:Retrieves the state of the AthViewpoint parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetAthViewpointInfo(io_admin_level, io_locked)

    def get_ps_cycle_time_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPSCycleTimeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PSCycleTime
                |     parameter.
                |     Role:Retrieves the state of the PSCycleTime parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetPSCycleTimeInfo(io_admin_level, io_locked)

    def get_ps_dyn_clash_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPSDynClashModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PSDynClashMode
                |     parameter.
                |     Role:Retrieves the state of the PSDynClashMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetPSDynClashModeInfo(io_admin_level, io_locked)

    def get_ps_graphic_sim_step_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPSGraphicSimStepInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PSGraphicSimStep
                |     parameter.
                |     Role:Retrieves the state of the PSGraphicSimStep parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetPSGraphicSimStepInfo(io_admin_level, io_locked)

    def get_ps_graphic_update_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPSGraphicUpdateInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PSGraphicUpdate
                |     parameter.
                |     Role:Retrieves the state of the PSGraphicUpdate parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetPSGraphicUpdateInfo(io_admin_level, io_locked)

    def get_pv_end_condition_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPVEndConditionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PVEndCondition
                |     parameter.
                |     Role:Retrieves the state of the PVEndCondition parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetPVEndConditionInfo(io_admin_level, io_locked)

    def get_pv_state_mgt_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPVStateMgtInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PVStateMgt
                |     parameter.
                |     Role:Retrieves the state of the PVStateMgt parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetPVStateMgtInfo(io_admin_level, io_locked)

    def get_run_annot_behavior_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunAnnotBehaviorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunAnnotBehavior
                |     parameter.
                |     Role:Retrieves the state of the RunAnnotBehavior parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunAnnotBehaviorInfo(io_admin_level, io_locked)

    def get_run_annotation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunAnnotationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunAnnotation
                |     parameter.
                |     Role:Retrieves the state of the RunAnnotation parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunAnnotationInfo(io_admin_level, io_locked)

    def get_run_end_condition_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunEndConditionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunEndCondition
                |     parameter.
                |     Role:Retrieves the state of the RunEndCondition parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunEndConditionInfo(io_admin_level, io_locked)

    def get_run_hlnk_behavior_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunHlnkBehaviorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunHlnkBehavior
                |     parameter.
                |     Role:Retrieves the state of the RunHlnkBehavior parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunHlnkBehaviorInfo(io_admin_level, io_locked)

    def get_run_hyperlink_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunHyperlinkInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunHyperlink
                |     parameter.
                |     Role:Retrieves the state of the RunHyperlink parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunHyperlinkInfo(io_admin_level, io_locked)

    def get_run_pause_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunPauseInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunPause
                |     parameter.
                |     Role:Retrieves the state of the RunPause parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunPauseInfo(io_admin_level, io_locked)

    def get_run_state_mgt_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunStateMgtInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunStateMgt
                |     parameter.
                |     Role:Retrieves the state of the RunStateMgt parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunStateMgtInfo(io_admin_level, io_locked)

    def get_run_step_size_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunStepSizeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunStepSize
                |     parameter.
                |     Role:Retrieves the state of the RunStepSize parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunStepSizeInfo(io_admin_level, io_locked)

    def get_run_text_behavior_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunTextBehaviorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunTextBehavior
                |     parameter.
                |     Role:Retrieves the state of the RunTextBehavior parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunTextBehaviorInfo(io_admin_level, io_locked)

    def get_run_text_msg_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunTextMsgInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunTextMsg
                |     parameter.
                |     Role:Retrieves the state of the RunTextMsg parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunTextMsgInfo(io_admin_level, io_locked)

    def get_run_viewpoint_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunViewpointInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunViewpoint
                |     parameter.
                |     Role:Retrieves the state of the RunViewpoint parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunViewpointInfo(io_admin_level, io_locked)

    def get_run_vis_behavior_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRunVisBehaviorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RunVisBehavior
                |     parameter.
                |     Role:Retrieves the state of the RunVisBehavior parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.simulation_setting_att.GetRunVisBehaviorInfo(io_admin_level, io_locked)

    def set_as_navigation_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetASNavigationModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ASNavigationMode parameter.
                |     Role:Locks or unlocks the ASNavigationMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetASNavigationModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_as_navigation_mode_lock'
        # # vba_code = """
        # # Public Function set_as_navigation_mode_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetASNavigationModeLock iLocked
        # #     set_as_navigation_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_as_step_size_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetASStepSizeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ASStepSize parameter.
                |     Role:Locks or unlocks the ASStepSize parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetASStepSizeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_as_step_size_lock'
        # # vba_code = """
        # # Public Function set_as_step_size_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetASStepSizeLock iLocked
        # #     set_as_step_size_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ath_annotation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAthAnnotationLock(boolean iLocked)
                | 
                |     Locks or unlocks the AthAnnotation parameter.
                |     Role:Locks or unlocks the AthAnnotation parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetAthAnnotationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ath_annotation_lock'
        # # vba_code = """
        # # Public Function set_ath_annotation_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetAthAnnotationLock iLocked
        # #     set_ath_annotation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ath_disable_sim_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAthDisableSimLock(boolean iLocked)
                | 
                |     Locks or unlocks the AthDisableSim parameter.
                |     Role:Locks or unlocks the AthDisableSim parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetAthDisableSimLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ath_disable_sim_lock'
        # # vba_code = """
        # # Public Function set_ath_disable_sim_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetAthDisableSimLock iLocked
        # #     set_ath_disable_sim_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ath_end_condition_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAthEndConditionLock(boolean iLocked)
                | 
                |     Locks or unlocks the AthEndCondition parameter.
                |     Role:Locks or unlocks the AthEndCondition parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetAthEndConditionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ath_end_condition_lock'
        # # vba_code = """
        # # Public Function set_ath_end_condition_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetAthEndConditionLock iLocked
        # #     set_ath_end_condition_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ath_hyperlink_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAthHyperlinkLock(boolean iLocked)
                | 
                |     Locks or unlocks the AthHyperlink parameter.
                |     Role:Locks or unlocks the AthHyperlink parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetAthHyperlinkLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ath_hyperlink_lock'
        # # vba_code = """
        # # Public Function set_ath_hyperlink_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetAthHyperlinkLock iLocked
        # #     set_ath_hyperlink_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ath_sel_agent_dlg_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAthSelAgentDlgLock(boolean iLocked)
                | 
                |     Locks or unlocks the AthSelAgentDlg parameter.
                |     Role:Locks or unlocks the AthSelAgentDlg parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetAthSelAgentDlgLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ath_sel_agent_dlg_lock'
        # # vba_code = """
        # # Public Function set_ath_sel_agent_dlg_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetAthSelAgentDlgLock iLocked
        # #     set_ath_sel_agent_dlg_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ath_state_mgt_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAthStateMgtLock(boolean iLocked)
                | 
                |     Locks or unlocks the AthStateMgt parameter.
                |     Role:Locks or unlocks the AthStateMgt parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetAthStateMgtLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ath_state_mgt_lock'
        # # vba_code = """
        # # Public Function set_ath_state_mgt_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetAthStateMgtLock iLocked
        # #     set_ath_state_mgt_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ath_text_msg_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAthTextMsgLock(boolean iLocked)
                | 
                |     Locks or unlocks the AthTextMsg parameter.
                |     Role:Locks or unlocks the AthTextMsg parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetAthTextMsgLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ath_text_msg_lock'
        # # vba_code = """
        # # Public Function set_ath_text_msg_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetAthTextMsgLock iLocked
        # #     set_ath_text_msg_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ath_viewpoint_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAthViewpointLock(boolean iLocked)
                | 
                |     Locks or unlocks the AthViewpoint parameter.
                |     Role:Locks or unlocks the AthViewpoint parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetAthViewpointLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ath_viewpoint_lock'
        # # vba_code = """
        # # Public Function set_ath_viewpoint_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetAthViewpointLock iLocked
        # #     set_ath_viewpoint_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ps_cycle_time_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPSCycleTimeLock(boolean iLocked)
                | 
                |     Locks or unlocks the PSCycleTime parameter.
                |     Role:Locks or unlocks the PSCycleTime parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetPSCycleTimeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ps_cycle_time_lock'
        # # vba_code = """
        # # Public Function set_ps_cycle_time_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetPSCycleTimeLock iLocked
        # #     set_ps_cycle_time_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ps_dyn_clash_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPSDynClashModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the PSDynClashMode parameter.
                |     Role:Locks or unlocks the PSDynClashMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetPSDynClashModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ps_dyn_clash_mode_lock'
        # # vba_code = """
        # # Public Function set_ps_dyn_clash_mode_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetPSDynClashModeLock iLocked
        # #     set_ps_dyn_clash_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ps_graphic_sim_step_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPSGraphicSimStepLock(boolean iLocked)
                | 
                |     Locks or unlocks the PSGraphicSimStep parameter.
                |     Role:Locks or unlocks the PSGraphicSimStep parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetPSGraphicSimStepLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ps_graphic_sim_step_lock'
        # # vba_code = """
        # # Public Function set_ps_graphic_sim_step_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetPSGraphicSimStepLock iLocked
        # #     set_ps_graphic_sim_step_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ps_graphic_update_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPSGraphicUpdateLock(boolean iLocked)
                | 
                |     Locks or unlocks the PSGraphicUpdate parameter.
                |     Role:Locks or unlocks the PSGraphicUpdate parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetPSGraphicUpdateLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ps_graphic_update_lock'
        # # vba_code = """
        # # Public Function set_ps_graphic_update_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetPSGraphicUpdateLock iLocked
        # #     set_ps_graphic_update_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pv_end_condition_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPVEndConditionLock(boolean iLocked)
                | 
                |     Locks or unlocks the PVEndCondition parameter.
                |     Role:Locks or unlocks the PVEndCondition parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetPVEndConditionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pv_end_condition_lock'
        # # vba_code = """
        # # Public Function set_pv_end_condition_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetPVEndConditionLock iLocked
        # #     set_pv_end_condition_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pv_state_mgt_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPVStateMgtLock(boolean iLocked)
                | 
                |     Locks or unlocks the PVStateMgt parameter.
                |     Role:Locks or unlocks the PVStateMgt parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetPVStateMgtLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pv_state_mgt_lock'
        # # vba_code = """
        # # Public Function set_pv_state_mgt_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetPVStateMgtLock iLocked
        # #     set_pv_state_mgt_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_annot_behavior_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunAnnotBehaviorLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunAnnotBehavior parameter.
                |     Role:Locks or unlocks the RunAnnotBehavior parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunAnnotBehaviorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_annot_behavior_lock'
        # # vba_code = """
        # # Public Function set_run_annot_behavior_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunAnnotBehaviorLock iLocked
        # #     set_run_annot_behavior_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_annotation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunAnnotationLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunAnnotation parameter.
                |     Role:Locks or unlocks the RunAnnotation parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunAnnotationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_annotation_lock'
        # # vba_code = """
        # # Public Function set_run_annotation_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunAnnotationLock iLocked
        # #     set_run_annotation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_end_condition_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunEndConditionLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunEndCondition parameter.
                |     Role:Locks or unlocks the RunEndCondition parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunEndConditionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_end_condition_lock'
        # # vba_code = """
        # # Public Function set_run_end_condition_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunEndConditionLock iLocked
        # #     set_run_end_condition_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_hlnk_behavior_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunHlnkBehaviorLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunHlnkBehavior parameter.
                |     Role:Locks or unlocks the RunHlnkBehavior parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunHlnkBehaviorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_hlnk_behavior_lock'
        # # vba_code = """
        # # Public Function set_run_hlnk_behavior_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunHlnkBehaviorLock iLocked
        # #     set_run_hlnk_behavior_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_hyperlink_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunHyperlinkLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunHyperlink parameter.
                |     Role:Locks or unlocks the RunHyperlink parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunHyperlinkLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_hyperlink_lock'
        # # vba_code = """
        # # Public Function set_run_hyperlink_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunHyperlinkLock iLocked
        # #     set_run_hyperlink_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_pause_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunPauseLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunPause parameter.
                |     Role:Locks or unlocks the RunPause parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunPauseLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_pause_lock'
        # # vba_code = """
        # # Public Function set_run_pause_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunPauseLock iLocked
        # #     set_run_pause_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_state_mgt_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunStateMgtLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunStateMgt parameter.
                |     Role:Locks or unlocks the RunStateMgt parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunStateMgtLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_state_mgt_lock'
        # # vba_code = """
        # # Public Function set_run_state_mgt_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunStateMgtLock iLocked
        # #     set_run_state_mgt_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_step_size_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunStepSizeLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunStepSize parameter.
                |     Role:Locks or unlocks the RunStepSize parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunStepSizeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_step_size_lock'
        # # vba_code = """
        # # Public Function set_run_step_size_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunStepSizeLock iLocked
        # #     set_run_step_size_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_text_behavior_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunTextBehaviorLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunTextBehavior parameter.
                |     Role:Locks or unlocks the RunTextBehavior parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunTextBehaviorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_text_behavior_lock'
        # # vba_code = """
        # # Public Function set_run_text_behavior_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunTextBehaviorLock iLocked
        # #     set_run_text_behavior_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_text_msg_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunTextMsgLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunTextMsg parameter.
                |     Role:Locks or unlocks the RunTextMsg parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunTextMsgLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_text_msg_lock'
        # # vba_code = """
        # # Public Function set_run_text_msg_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunTextMsgLock iLocked
        # #     set_run_text_msg_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_viewpoint_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunViewpointLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunViewpoint parameter.
                |     Role:Locks or unlocks the RunViewpoint parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunViewpointLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_viewpoint_lock'
        # # vba_code = """
        # # Public Function set_run_viewpoint_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunViewpointLock iLocked
        # #     set_run_viewpoint_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_run_vis_behavior_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRunVisBehaviorLock(boolean iLocked)
                | 
                |     Locks or unlocks the RunVisBehavior parameter.
                |     Role:Locks or unlocks the RunVisBehavior parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.simulation_setting_att.SetRunVisBehaviorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_run_vis_behavior_lock'
        # # vba_code = """
        # # Public Function set_run_vis_behavior_lock(simulation_setting_att)
        # #     Dim iLocked (2)
        # #     simulation_setting_att.SetRunVisBehaviorLock iLocked
        # #     set_run_vis_behavior_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SimulationSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.sketch_based_shape import SketchBasedShape


class SolidCombine(SketchBasedShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SketchBasedShape
                |                             SolidCombine
                | 
                | The interface to access a CATIASolidCombine.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.solid_combine = com_object

    @property
    def first_component_direction(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstComponentDirection() As Reference
                | 
                |     Returns or sets the direction of first component of
                |     SolidCombine.
                | 
                |     Example:
                |         The following example returns in firstDirection the direction of first
                |         component of firstSolidCombine SolidCombine feature, and then sets it to the
                |         firstDirection2 direction element.
                | 
                |          Set firstDirection = firstSolidCombine.FirstComponentDirection
                |          Set firstSolidCombine.FirstComponentDirection = firstDirection2

        :rtype: Reference
        """

        return Reference(self.solid_combine.FirstComponentDirection)

    @first_component_direction.setter
    def first_component_direction(self, value: Reference):
        """
        :param Reference value:
        """

        self.solid_combine.FirstComponentDirection = value.com_object

    @property
    def first_component_profile(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstComponentProfile() As Reference
                | 
                |     Returns or sets the profile of first component of
                |     SolidCombine.
                | 
                |     Example:
                |         The following example returns in firstProfile the profile of first
                |         component of firstSolidCombine SolidCombine feature, and then sets it to the
                |         firstProfile2 profile element:
                | 
                |          Set firstProfile = firstSolidCombine.FirstComponentProfile
                |          Set firstSolidCombine.FirstComponentProfile = firstProfile2

        :rtype: Reference
        """

        return Reference(self.solid_combine.FirstComponentProfile)

    @first_component_profile.setter
    def first_component_profile(self, value: Reference):
        """
        :param Reference value:
        """

        self.solid_combine.FirstComponentProfile = value.com_object

    @property
    def second_component_direction(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondComponentDirection() As Reference
                | 
                |     Returns or sets the direction of second component of
                |     SolidCombine.
                | 
                |     Example:
                |         The following example returns in secondDirection the direction of
                |         second component of firstSolidCombine SolidCombine feature, and then sets it to
                |         the secondDirection2 direction element.
                | 
                |          Set secondDirection = firstSolidCombine.SecondComponentDirection
                |          Set firstSolidCombine.SecondComponentDirection = secondDirection2

        :rtype: Reference
        """

        return Reference(self.solid_combine.SecondComponentDirection)

    @second_component_direction.setter
    def second_component_direction(self, value: Reference):
        """
        :param Reference value:
        """

        self.solid_combine.SecondComponentDirection = value.com_object

    @property
    def second_component_profile(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondComponentProfile() As Reference
                | 
                |     Returns or sets the profile of second component of
                |     SolidCombine.
                | 
                |     Example:
                |         The following example returns in secondProfile the profile of second
                |         component of firstSolidCombine SolidCombine feature, and then sets it to the
                |         secondProfile2 profile element:
                | 
                |          Set secondProfile = firstSolidCombine.SecondComponentProfile
                |          Set firstSolidCombine.SecondComponentProfile = secondProfile2

        :rtype: Reference
        """

        return Reference(self.solid_combine.SecondComponentProfile)

    @second_component_profile.setter
    def second_component_profile(self, value: Reference):
        """
        :param Reference value:
        """

        self.solid_combine.SecondComponentProfile = value.com_object

    def __repr__(self):
        return f'SolidCombine(name="{ self.name }")'



#! /usr/bin/python3.9
from typing import Iterator
import os
from pathlib import Path
import warnings

from pywintypes import com_error

from pycatia.exception_handling import CATIAApplicationException
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.collection import Collection
from pycatia.types.document import document_types
from pycatia.types.general import cat_variant, list_str


def get_document_object(doc_com):
    """

    """
    full_name = Path(doc_com.FullName)
    extension = full_name.suffix[1:]
    types = [document_types[k]['type'] for k in document_types if document_types[k]['extension'] == extension]
    if not types:
        document_type = document_types['Default']['type']
    else:
        document_type = types[0]

    return document_type(doc_com)


class Documents(Collection):
    """
    The Documents object is used to access multiple open documents in the catia session.

    Usage::

        >>> from pycatia import catia
        >>> caa = catia()
        >>> documents = caa.documents

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Documents
                |
                | A collection of all the Document objects currently managed by the
                | application.
                | These documents belong to one of the following types: PartDocument,
                | ProductDocument, and Drawing.
                |
                | See also:
                |     PartDocument, ProductDocument, DrawingDocument

    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Document)
        self.documents = com_object
        self.child_object = Document

    def add(self, document_type) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(CATBSTR docType) As Document
                |
                |     Creates a Document object and adds it to the documents collection. This
                |     document becomes the active one, and a window is created to accomodate it which
                |     becomes the active window.
                |
                |     Parameters:
                |
                |         docType
                |             The type of the document to create, chosen among:
                |
                |             Part
                |                 For PartDocument
                |             Product
                |                 For ProductDocument
                |             Drawing
                |                 For Drawing
                |
                |     Returns:
                |         The created document
                |     Example:
                |         The following example creates a PartDocument document in the collection
                |         retrieved in PartDoc.
                |
                |          Dim PartDoc As Document
                |          Set PartDoc = Documents.Add("Part")

        :param str document_type:
        :rtype: Document
        """

        # see pycatia.types.docs for supported Documents.

        if document_type.lower() not in [t.lower() for t in document_types]:
            raise CATIAApplicationException(
                f'Document type {document_type} not supported. Allowed types are {[t for t in document_types]}.')

        document = document_types[document_type]['type']

        return document(self.documents.Add(document_type))

    def count_types(self, file_type_list: list_str) -> int:
        """
        Returns the number of documents which presents special file extensions like:
            'catpart', 'catdrawing', 'catproduct', 'catmaterial', 'catalog', 'catfct'


        :param list_str file_type_list: filetype(s) to count. can be list or string.
        :return: int()
        """

        items = self.get_item_names()

        if isinstance(file_type_list, str):
            type_list = [elem.lower() for elem in [file_type_list]]
        elif isinstance(file_type_list, list):
            type_list = [elem.lower() for elem in file_type_list]
        else:
            raise CATIAApplicationException(f'File type list {file_type_list} not valid type.')

        return len([True for name in items for typ in type_list if name.lower().find(typ) > 0])

    def new_from(self, file_name: Path) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func NewFrom(CATBSTR iFileName) As Document
                |
                |     Creates a new document from a document stored in a file. Role: Reads a
                |     document stored in a file and creates a new document containing the resulting
                |     data, adds the new document to the document collection, displays it in a new
                |     window, adds the window to the window collection and activates both the
                |     document and the window.
                |
                |     Parameters:
                |
                |         The
                |             name of the file containing the document.
                |
                |     Returns:
                |         The created document.
                |     Example:
                |         The following example creates a new Doc document from the contents of
                |         the FileToRead file.
                |
                |          FileToRead = "e:\\users\\psr\\Parts\\ThisIsANicePart.CATPart"
                |          Dim Doc As Document
                |          Set Doc = Documents.NewFrom(FileToRead)

        :param Path file_name:
        :rtype: Document
        """

        # legacy support for strings.
        if type(file_name) is str:
            file_name = Path(file_name)

        if not file_name.is_file():
            raise FileNotFoundError(f'Could not find file {file_name}.')

        return Document(self.documents.NewFrom(file_name))

    def item(self, index: cat_variant) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As Document
                |
                |     Returns a document using its index or its name from the documents
                |     collection.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index or the name of the document to retrieve frm the
                |             collection of documents. As a numerics, this index is the rank of the document
                |             in the collection. The index of the first document in the collection is 1, and
                |             the index of the last document is Count. As a string, it is the name you
                |             assigned to the document using the
                |
                |         AnyObject.Name property.
                |     Returns:
                |         The retrieved document
                |     Example:
                |         This example retrieves in ThisDoc the fifth document in the collection
                |         and in ThatDoc the document named MyDoc.
                |
                |          Dim ThisDoc As Document
                |          Set ThisDoc = Documents.Item(5)
                |          Dim ThatDoc As Document
                |          Set ThatDoc = Documents.Item("MyDoc")

        :param cat_variant index:
        :rtype: Document
        """
        try:
            item_doc_com = self.documents.Item(index)
            return get_document_object(item_doc_com)
        except com_error:
            raise IndexError('list index out of range')

    def num_open(self) -> int:
        """
        Returns the number of open documents.

        .. warning::

            The COM object can return the incorrect number of documents open. After a document is closed CATIA can keep
            the linked document `ABQMaterialPropertiesCatalog.CATfct` open.

        :rtype: int
        """

        # for i in range(0, self.documents.Count):
        #     print(self.documents.Item(i + 1).Name)

        self.logger.warning('The Documents.num_open method is unreliable and will be deprecated in future versions.')
        return self.documents.Count

    def open(self, file_name: Path) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Open(CATBSTR iFileName) As Document
                |
                |     Opens a document stored in a file. Reads a document stored in a file,
                |     displays it in a new window, adds the document to the documents collection and
                |     the window to the windows collection, and makes both the document and the
                |     window the active ones.
                |
                |     Parameters:
                |
                |         iFileName
                |             The name of the file containing the document
                |
                |     Returns:
                |         The retrieved document
                |     Example:
                |         The following example opens the Doc document contained in the
                |         FileToOpen file.
                |
                |          FileToOpen = "e:\\users\\psr\\Parts\\ThisIsANicePart.CATPart"
                |          Dim Doc As Document
                |          Set Doc = Documents.Open(FileToOpen)

        :param Path file_name:
        :rtype: Document
        """

        # legacy support for strings.
        if type(file_name) is str:
            file_name = Path(file_name)

        if not file_name.is_file():
            raise FileNotFoundError(f'Could not find file {file_name}.')

        self.logger.info(f'Opening document "{file_name}".')
        try:
            open_doc_com = self.documents.Open(file_name)
            return get_document_object(open_doc_com)
        except com_error:
            raise CATIAApplicationException(
                f'Could not OPEN document "{file_name}". '
                'Check file type and ensure the version of CATIA it was created with is compatible.')

    def read(self, file_name: Path) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Read(CATBSTR iFileName) As Document
                |
                |     Reads a document stored in a file. This method has to be used only for
                |     Browse purpose, for instance to retrieve Product properties. Be careful, it
                |     doesn't open any editor (no visualization, no undo/redo capabilities...) As
                |     soon as you want to modify the V5 document, you have to use the VB Open method
                |     collection. If this solution is not satisfactory because it opens an editor for
                |     every document, you have to move to C++ and use the CAA methods
                |     CATDocumentServices::Open and CATDocumentServices::SaveAs with the same file
                |     name as the initial one.
                |
                |     Parameters:
                |
                |         iFileName
                |             The name of the file containing the document
                |
                |     Returns:
                |         The retrieved document
                |     Example:
                |         The following example reads the Doc document contained in the
                |         FileToOpen file.
                |
                |          FileToOpen = "e:\\users\\psr\\Parts\\ThisIsANicePart.CATPart"
                |          Dim Doc As Document
                |          Set Doc = Documents.Read(FileToOpen)

        :param str file_name:
        :rtype: Document
        """
        # return Document(self.documents.Read(file_name))

        # legacy support for strings.
        if type(file_name) is str:
            file_name = Path(file_name)

        if not file_name.is_file():
            raise FileNotFoundError(f'Could not find file {file_name}.')

        self.logger.info(f'Reading document "{file_name}".')
        try:
            read_doc_com = self.documents.Read(file_name)
            return get_document_object(read_doc_com)
        except com_error:
            raise CATIAApplicationException(
                f'Could not READ document "{file_name}". '
                'Check file type and ensure the version of CATIA it was created with is compatible.')

    def __getitem__(self, n: int) -> Document:
        if (n + 1) > self.count:
            raise StopIteration

        return get_document_object(self.documents.Item(n + 1))

    def __iter__(self) -> Iterator[Document]:
        for i in range(self.count):
            yield get_document_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Documents(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_profile import SFMProfile
from pycatia.cat_str_functional_interfaces.sfm_welds import SFMWelds
from pycatia.in_interfaces.reference import Reference


class SFMMember(SFMProfile):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATStrFunctionalInterfaces.SfmObject
                |                         CATStrFunctionalInterfaces.SfmProfile
                |                             SfmMember
                | 
                | Interface to manage the structure frame modeling member object Role: Allows
                | accessing and setting of member's data.
                | 
                | See also:
                |     SfmFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_member = com_object

    def flip(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Flip()
                | 
                |     Flip the member's section according to X axis.
                | 
                |     Example:
                |         This example flips the section of the SfmMember
                |         feature.
                | 
                |          SfmMember.Flip

        :rtype: None
        """
        return self.sfm_member.Flip()

    def get_member_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMemberType() As CATBSTR
                | 
                |     Returns the Type of Member (SfmMemberPointLength, SfmMemberPointLimit, SfmMember2Points,
                |                                 SfmMemberCurve,SfmMemberMembersPlane,SfmMemberSurfSurf)
                |
                |     Example:
                |         This example retrieves the Type of Existing Member.
                | 
                |          Dim Name As String
                |          Name = SfmMemberObj.GetMemberType

        :rtype: str
        """
        return self.sfm_member.GetMemberType()

    def get_welds(self, i_operating_ele: Reference) -> SFMWelds:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWelds(Reference iOperatingEle) As SfmWelds
                | 
                |     Returns the weld features on the Existing Member.
                | 
                |     Example:
                |         This example retrieves the number of weld features on the Existing
                |         Member.
                | 
                |          Dim DeckMember1 As SfmMember
                |          Set DeckMember1 = SelctionObj.FindObject("CATIASfmMember")
                |          Dim OperatedMemberObject As SfmMemberObject
                |          Set OperatedMemberObject = DeckMember1.GetItem("SfmMemberObject")
                |          Dim Welds As SfmWelds
                |          Set Welds = OperatedMemberObject.GetWelds(Nothing)

        :param Reference i_operating_ele:
        :rtype: SFMWelds
        """
        return SFMWelds(self.sfm_member.GetWelds(i_operating_ele.com_object))

    def is_flip(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsFlip() As boolean
                | 
                |     Get the flip status of the member's section.
                | 
                |     Example:
                |         This example retrieves in FlipStatus the flip status of the SfmMember
                |         feature.
                | 
                |          Dim FlipStatus As Boolean
                |          Set FlipStatus = SfmMember.IsFlip

        :rtype: bool
        """
        return self.sfm_member.IsFlip()

    def __repr__(self):
        return f'SFMMember(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SFMObject(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmObject
                | 
                | Interface to manage the category of a SfmObject.
                | Role: To manage SfmObject's category.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_object = com_object

    @property
    def category(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Category() As CATBSTR
                | 
                |     Returns or sets the category.
                | 
                |     Example:
                |         This example retrieves in Category the supporting curve for the
                |         SfmObject feature.
                | 
                |          Category = SfmObject.Category

        :rtype: str
        """

        return self.sfm_object.Category

    @category.setter
    def category(self, value: str):
        """
        :param str value:
        """

        self.sfm_object.Category = value

    @property
    def grade(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Grade() As CATBSTR
                | 
                |     Returns or sets the grade.
                | 
                |     Example:
                |         This example retrieves in Grade the informations for the
                |         SfmMaterialProperties feature.
                | 
                |          SfmMaterialProperties.Grade Grade

        :rtype: str
        """

        return self.sfm_object.Grade

    @grade.setter
    def grade(self, value: str):
        """
        :param str value:
        """

        self.sfm_object.Grade = value

    @property
    def material(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Material() As CATBSTR
                | 
                |     Returns or sets the material.
                | 
                |     Example:
                |         This example retrieves in Material the informations for the
                |         SfmMaterialProperties feature.
                | 
                |          SfmMaterialProperties.Material Material

        :rtype: str
        """

        return self.sfm_object.Material

    @material.setter
    def material(self, value: str):
        """
        :param str value:
        """

        self.sfm_object.Material = value

    def __repr__(self):
        return f'SFMObject(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class SFMConnectionParameters(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     SfmConnectionParameters
                | 
                | Interface to get the parameters defining the UDF for Slots and
                | Endcuts.
                | Role: To Get/Set the parameters of the UDF.
                | 
                | See also:
                |     SfmSlots, SfmEndcut, SfmEndcutManager
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Parameter)
        self.sfm_connection_parameters = com_object

    def item(self, i_index: cat_variant) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Parameter
                | 
                |     Gets a Item from the collection list.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             [in] Index of the item to be retrieved. 
                |         oStdConParm
                |             [out] The required parameter. 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example
                |         :
                |             This example retrieves and manipulates existing BuiltIn EndCut
                |             parameters.
                | 
                |              Dim oStartEndCutObj As SfmEndcut
                |              Set oStartEndCutObj = StiffObj.GetEndcut(1) 
                |              Dim oStartEndCutType,oStartEndCutName As String
                |              Dim oLimitContextList As SfmReferences
                |              Dim oConnectionParamList As
                |              SfmConnectionParameters
                |              Dim oConnectionParamNames() As Variant
                |              oStartEndCutObj.GetEndcutinfo oStartEndCutType, oStartEndCutName,
                |              oLimitContextList, oConnectionParamList, oConnectionParamNames 
                |              
                |              ' Reading Parameters
                |              Dim SizeOfUDFParams As Long
                |              SizeOfUDFParams = oConnectionParamList.Count
                |              Dim UDFParam As Parameter
                |              Dim UDFParamName, UDFParamValue As String
                |              For i = 1 To SizeOfUDFParams
                |               Set UDFParam = oConnectionParamList.Item(i)
                |               UDFParamName = oConnectionParamNames(i - 1)
                |               UDFParamValue = UDFParam.ValueAsString
                |              Next 
                |              ' Setting Parameters
                |              For j = 1 To SizeOfUDFParams
                |               Set UDFParam = oConnectionParamList.Item(j)
                |              UDFParamName = oConnectionParamNames(j - 1)
                |              If (UDFParamName = "A1") Then
                |                 UDFParam.ValuateFromString ("16deg")
                |                 End If
                |              If (UDFParamName = "A2") Then
                |                  UDFParam.ValuateFromString ("16deg")
                |                  End If
                |              If (UDFParamName = "B") Then
                |                  UDFParam.ValuateFromString ("31deg")
                |                  End If
                |              Next

        :param cat_variant i_index:
        :rtype: Parameter
        """
        return Parameter(self.sfm_connection_parameters.Item(i_index))

    def __repr__(self):
        return f'SFMConnectionParameters(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_robot_interfaces.parameter_profiles import ParameterProfiles


class OperationProfile(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         OperationProfile
                | 
                | Represents an Operation.
                | 
                | Role: The interface is used to manage the attributes of an
                | Operation.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.operation_profile = com_object

    def get_user_profiles_list(self, i_profile_type: str, o_profiles: tuple) -> ParameterProfiles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetUserProfilesList(CATBSTR iProfileType,
                | CATSafeArrayVariant oProfiles)
                | 
                |     Retreives the list of User Profiles for the Operation.
                | 
                |     Parameters:
                | 
                |         iProfileType
                |             if iType specified, only a list of that type inside the User
                |             Profiles List will be returned if iType is an empty string, all the User
                |             Profiles are returned 
                |         oProfiles
                |             The List of User Profiles. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             List of User Profiles is successfully returned
                |         E_FAIL
                |             List of User Profiles could not be obtained
                | 
                |     Example:
                |
                |            Dim objOperProfile As OperationProfile
                |            Dim ProfileType as String
                |            ProfileType=""
                |                   ......
                |            Dim MyListOfProfiles() As ParameterProfiles 
                |            objOperProfile.GetUserProfilesList ProfileType,
                |            MyListOfProfiles
                |            ..

        :param str i_profile_type:
        :param tuple o_profiles:
        :rtype: ParameterProfiles
        """
        return ParameterProfiles(self.operation_profile.GetUserProfilesList(i_profile_type, o_profiles))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_user_profiles_list'
        # # vba_code = """
        # # Public Function get_user_profiles_list(operation_profile)
        # #     Dim iProfileType (2)
        # #     operation_profile.GetUserProfilesList iProfileType
        # #     get_user_profiles_list = iProfileType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_user_profiles_list(self, i_user_profiles: tuple) -> ParameterProfiles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUserProfilesList(CATSafeArrayVariant iUserProfiles)
                | 
                |     Sets User Profiles List for the Operation.
                | 
                |     Parameters:
                | 
                |         iUserProfiles
                |             The List of User Profiles to be set. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The List of User Profiles was successfully set.
                |         E_FAIL
                |             The List of User Profiles could not be set.
                | 
                |         Example:
                |             The following example sets the user profiles list for an
                |             Operation.
                | 
                |                Dim objOperProfile as OperationProfile
                |                Dim MyListOfProfiles() As ParameterProfiles
                |                ...
                |                ...
                |                objOperProfile.SetUserProfilesList
                |                MyListOfProfiles

        :param tuple i_user_profiles:
        :rtype: ParameterProfiles
        """
        return ParameterProfiles(self.operation_profile.SetUserProfilesList(i_user_profiles))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_user_profiles_list'
        # # vba_code = """
        # # Public Function set_user_profiles_list(operation_profile)
        # #     Dim iUserProfiles (2)
        # #     operation_profile.SetUserProfilesList iUserProfiles
        # #     set_user_profiles_list = iUserProfiles
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'OperationProfile(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.assembly_interfaces.assembly_feature import AssemblyFeature
from pycatia.knowledge_interfaces.parameter import Parameter


class StrCutback(AssemblyFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAssemblyInterfaces.AssemblyFeature
                |                         StrCutback
                | 
                | Represents the cutback object.
                | It is aggregated to an extremity of a member. It can be retrieved using the
                | StrMemberExtremity object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_cutback = com_object

    @property
    def offset(self) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Offset() As Parameter (Read Only)
                | 
                |     Returns the parameter defining the offset.

        :rtype: Parameter
        """

        return Parameter(self.str_cutback.Offset)

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CatStrCutbackType (Read Only)
                | 
                |     Returns the type of the cutback object.
                | 
                |     Example:
                |         This example retrieves the type for the StrMember
                |         object.
                | 
                |          Type = Member.Type

        :return: enum cat_str_cutback_type
        :rtype: int
        """

        return self.str_cutback.Type

    def __repr__(self):
        return f'StrCutback(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_references import SFMReferences
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.cat_base_unknown import CATBaseUnknown
from pycatia.types.general import cat_variant


class SFMStandardPosStrategyParameters(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmStandardPosStrategyParameters
                | 
                | Sets the Required data for Positioning the Contour.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_standard_pos_strategy_parameters = com_object

    @property
    def count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Count() As long (Read Only)
                | 
                |     Returns the count of reference elements.
                | 
                |     Example
                |     :
                |         This example retrieves gets the count of the
                |         References
                | 
                |          Cnt = VrefList.Count

        :rtype: int
        """

        return self.sfm_standard_pos_strategy_parameters.Count

    def item(self, i_index: cat_variant) -> CATBaseUnknown:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As CATBaseUnknown

        :param cat_variant i_index:
        :rtype: CATBaseUnknown
        """
        return self.sfm_standard_pos_strategy_parameters.Item(i_index)

    def set_pos_param_data(
            self,
            i_pos_strategy_name: str,
            i_rotation_angle: float,
            i_uref_elem: SFMReferences,
            i_u_offset: float,
            i_v_ref_elem: SFMReferences,
            i_v_offset: float
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosParamData(CATBSTR iPosStrategyName,
                | double iRotationAngle,
                | SfmReferences iUrefElem,
                | double iUOffset,
                | SfmReferences iVRefElem,
                | double iVOffset)
                | 
                |     Sets the Position Parameter Data for different Strategies.Different
                |     Strategies require different inputs.
                | 
                |     Parameters:
                | 
                |         iPosStrategyName
                |             [in] Legal Values:
                |             CATSfmPosOffsetOffset,CATSfmPosHalfHeightOffset,CATSfmPosMidDistOffset,CATSfmPosMidDistMidDist,CATSfmPosHalfHeightMidDist
                |             
                |         iRotationAngle
                |             [in] Enter Rotaion angle for Contour 
                |         iUrefElem
                |             [in] List of U reference Elements CATSfmPosOffsetOffset: This
                |             Strategy can take Multiple U References CATSfmPosHalfHeightOffset: This
                |             Strategy can take Multiple U References CATSfmPosMidDistOffset: This Strategy
                |             can take Multiple U References CATSfmPosMidDistMidDist: This strategy can take
                |             Multiple U References CATSfmPosHalfHeightMidDist: This strategy can take
                |             Multiple U References 
                |         iUOffset
                |             [in] Enter U Offset value 
                |         iVrefElem
                |             [in] List of V reference Elements CATSfmPosOffsetOffset: This
                |             Strategy can take only one V Reference CATSfmPosHalfHeightOffset: This Strategy
                |             does not take any V Reference CATSfmPosMidDistOffset: This Strategy can take
                |             only one V Reference CATSfmPosMidDistMidDist: This strategy can take only two V
                |             References CATSfmPosHalfHeightMidDist: This Strategy does not take any V
                |             Reference 
                |         iVOffset
                |             [in] Enter V Offset value 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This example sets the data required for Positioning the Contour for
                |             CATSfmPosMidDistMidDist in details.
                | 
                |              'For MidDistance-MidDistance Strategy
                |              'Populate List for U references with 4 Reference
                |              elements
                |              Dim UrefList As SfmReferences
                |              Dim Uref1,Uref2,Uref3,Uref4 As Reference
                |              Set Uref1 = Part1.FindObjectByName("CROSS.95")
                |              Set Uref2 = Part1.FindObjectByName("CROSS.50")
                |              Set Uref3 = Part1.FindObjectByName("CROSS.25")
                |              Set Uref4 = Part1.FindObjectByName("CROSS.40")
                |              Set UrefList = Factory.SfmReferences
                |              UrefList.Add Uref1
                |              UrefList.Add Uref2
                |              UrefList.Add Uref3
                |              UrefList.Add Uref4
                |              'Populate List for V references with 2 Reference
                |              elements
                |              Dim VrefList As SfmReferences
                |              Dim Vref1,Vref2 As Reference
                |              Set Vref1 = Part1.FindObjectByName("LONG.0")
                |              Set Vref2 = Part1.FindObjectByName("LONG.10")
                |              Set VrefList = Factory.SfmReferences
                |              VrefList.Add Vref1
                |              VrefList.Add Vref2
                |              'Set the SfmStandardPosStrategyParameters
                |              Dim PositionStrategyParms As
                |              SfmStandardPosStrategyParameters
                |              Set PositionStrategyParms = ObjSfmPosStrategyMgr.GetPositioningStrategyParams("CATSfmPosMidDistMidDist")
                |              'Get the Count of U References
                |              Dim NbofURef As Long
                |              NbofURef = UrefList.Count
                |              'The Following list will will pass only first two U references.
                |              The next two references will be passed after clearing the
                |              list
                |              Dim URefListinternal As SfmReferences
                |              Set URefListinternal = Factory.SfmReferences
                |              Dim StdOpening As SfmStandardOpening
                |              ' For loop
                |              For nUrefCnt = 1 To NbofURef Step 2
                |                If (nUrefCnt + 1) <= NbofURef Then
                |                 URefListinternal.Add UrefList.Item(nUrefCnt)
                |                 URefListinternal.Add UrefList.Item(nUrefCnt +
                |                 1)
                |                 PositionStrategyParms.SetPosParamData
                |                 "CATSfmPosMidDistMidDist", 20, URefListinternal, 0, VrefList,
                |                 0
                |                 Set StdOpening = Factory.CreateStandardOpening("FunctionalOpening",
                |                                                                "Sfm_Rect",
                |                                                                oListCkeParms,
                |                                                                "CATSfmPosMidDistMidDist",
                |                                                                PositionStrategyParms,
                |                                                                plateref)
                |                 URefListinternal.ClearList
                |                End If
                |              Next
                |              Part1.Update
                |              ' Example for CATSfmPosOffsetOffset Strategy: VRefList Contains
                |              only one Reference element
                |              Dim PositionStrategyParms As
                |              SfmStandardPosStrategyParameters
                |              Set PositionStrategyParms = ObjSfmPosStrategyMgr.GetPositioningStrategyParams("CATSfmPosOffsetOffset")
                |              Dim StdOpening As SfmStandardOpening
                |              Dim URefListinternal As SfmReferences
                |              Set URefListinternal = Factory.SfmReferences
                |              For nUrefCnt = 1 To NbofURef
                |                  URefListinternal.Add UrefList.Item(nUrefCnt)
                |                  PositionStrategyParms.SetPosParamData "CATSfmPosOffsetOffset",
                |                  20, URefListinternal, 1, VrefList, 2
                |                  Set StdOpening = Factory.CreateStandardOpening("FunctionalOpening",
                |                                                                 "Sfm_Rect",
                |                                                                 oListCkeParms,
                |                                                                 "CATSfmPosOffsetOffset",
                |                                                                 PositionStrategyParms,
                |                                                                 plateref)
                |                  URefListinternal.ClearList
                |                  Part1.Update
                |               Next
                |               ' Example for CATSfmPosMidDistOffset Strategy: Uref elements are
                |               passed in group of two.VRefList Contains only one Reference element.
                |               
                |               For nUrefCnt = 1 To NbofURef Step 2
                |                  If (nUrefCnt + 1) <= NbofURef Then
                |                  URefListinternal.Add UrefList.Item(nUrefCnt)
                |                  URefListinternal.Add UrefList.Item(nUrefCnt +
                |                  1)
                |                  PositionStrategyParms.SetPosParamData
                |                  "CATSfmPosMidDistOffset", 20, URefListinternal, 0, VrefList,
                |                  22
                |                  Set StdOpening = Factory.CreateStandardOpening("FunctionalOpening",
                |                                                                 "Sfm_Rect",
                |                                                                 oListCkeParms,
                |                                                                 "CATSfmPosMidDistOffset",
                |                                                                 PositionStrategyParms,
                |                                                                 plateref)
                |                  URefListinternal.ClearList
                |                  End If
                |               Next
                |               ' Example for CATSfmPosHalfHeightOffset
                |               Strategy:
                |              For nUrefCnt = 1 To NbofURef
                |                  URefListinternal.Add UrefList.Item(nUrefCnt)
                |                  PositionStrategyParms.SetPosParamData
                |                  "CATSfmPosHalfHeightOffset", 20, URefListinternal, 0, VrefList,
                |                  0
                |                  Set StdOpening = Factory.CreateStandardOpening("FunctionalOpening",
                |                                                                 "Sfm_Rect",
                |                                                                 oListCkeParms,
                |                                                                 "CATSfmPosHalfHeightOffset",
                |                                                                 PositionStrategyParms,
                |                                                                 plateref)
                |                  URefListinternal.ClearList
                |                  Part1.Update
                |              Next
                |               ' Example for CATSfmPosHalfHeightMidDist Strategy:U Ref Elements
                |               are passed in Group of two.
                |              For nUrefCnt = 1 To NbofURef Step 2
                |                If (nUrefCnt + 1) <= NbofURef Then
                |                  URefListinternal.Add UrefList.Item(nUrefCnt)
                |                  URefListinternal.Add UrefList.Item(nUrefCnt +
                |                  1)
                |                  PositionStrategyParms.SetPosParamData
                |                  "CATSfmPosHalfHeightMidDist", 20, URefListinternal, 1, VrefList,
                |                  2
                |                  Set StdOpening = Factory.CreateStandardOpening("FunctionalOpening",
                |                                                                 "Sfm_Rect",
                |                                                                  oListCkeParms,
                |                                                                 "CATSfmPosHalfHeightMidDist",
                |                                                                 PositionStrategyParms,
                |                                                                 plateref)
                |                  URefListinternal.ClearList
                |                End If
                |              Next

        :param str i_pos_strategy_name:
        :param float i_rotation_angle:
        :param SFMReferences i_uref_elem:
        :param float i_u_offset:
        :param SFMReferences i_v_ref_elem:
        :param float i_v_offset:
        :rtype: None
        """
        return self.sfm_standard_pos_strategy_parameters.SetPosParamData(
            i_pos_strategy_name,
            i_rotation_angle,
            i_uref_elem.com_object,
            i_u_offset,
            i_v_ref_elem.com_object,
            i_v_offset
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pos_param_data'
        # # vba_code = """
        # # Public Function set_pos_param_data(sfm_standard_pos_strategy_parameters)
        # #     Dim iPosStrategyName (2)
        # #     sfm_standard_pos_strategy_parameters.SetPosParamData iPosStrategyName
        # #     set_pos_param_data = iPosStrategyName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SFMStandardPosStrategyParameters(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_igp_setup_interfaces.tag import Tag
from pycatia.knowledge_interfaces.list import List
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class MountManager(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MountManager
                | 
                | Represents the Mount Manger of a Robot.
                | 
                | Role: Mount Manager is the object used to access and manage the devices mounted
                | on the robot.
                | The following code snippet can be used to obtain the Mount Manager from the
                | robot product.
                | 
                |    Dim objMountManager As MountManager
                |    Dim objRobot as Product
                |    
                |    Set objMountManager = objRobot.GetTechnologicalObject("MountManager" )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mount_manager = com_object

    def get_mounted_devices(self, o_device_list: tuple) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMountedDevices(CATSafeArrayVariant oDeviceList)
                | 
                |     Retrieves the list of mounted devices on the Robot
                | 
                |     Parameters:
                | 
                |         oDeviceList
                |             Retrieved list of Mounted devices 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The list of mounted devices could be successfully retrieved from
                |             the robot.
                |         E_FAIL
                |             TThe list of mounted devices could be not be obtained from the
                |             robot
                | 
                |         Example:
                |             The following example retrieves the list of mounted devices on the
                |             Robot.
                | 
                |                Dim objMountManager As MountManager
                |                Dim DeviceList(3) As Product
                |                ..
                |                objMountManager.GetMountedDevices DeviceList

        :param tuple o_device_list:
        :rtype: Product
        """
        return Product(self.mount_manager.GetMountedDevices(o_device_list))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_mounted_devices'
        # # vba_code = """
        # # Public Function get_mounted_devices(mount_manager)
        # #     Dim oDeviceList (2)
        # #     mount_manager.GetMountedDevices oDeviceList
        # #     get_mounted_devices = oDeviceList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_device_mounted(self, i_device: Product, i_is_mounted: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsDeviceMounted(Product iDevice,
                | boolean iIsMounted)
                | 
                |     Checks if the device is mounted or not on a robot.
                | 
                |     Parameters:
                | 
                |         iDevice
                |             Device for which mount status needs to be checked 
                |         iIsMounted
                |             Retrieved result for the mount status- Mounted(1), Not Mounted(0)
                |
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The status could be successfully queried from the mount
                |             manager
                |         E_FAIL
                |             The query failed.
                | 
                |         Example:
                |             The following example retrieves the list of mounted devices on the
                |             Robot.
                | 
                |                Dim objMountManager As MountManager
                |                Dim Device As Product
                |                Dim IsMounted As Boolean
                |                ..
                |                objMountManager.IsDeviceMounted
                |                Device,IsMounted

        :param Product i_device:
        :param bool i_is_mounted:
        :rtype: None
        """
        return self.mount_manager.IsDeviceMounted(i_device.com_object, i_is_mounted)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_device_mounted'
        # # vba_code = """
        # # Public Function is_device_mounted(mount_manager)
        # #     Dim iDevice (2)
        # #     mount_manager.IsDeviceMounted iDevice
        # #     is_device_mounted = iDevice
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def mount_device(
            self,
            i_device: Product,
            i_tool_profile_name: str,
            i_mount_offset: tuple,
            i_tool_mobility: bool,
            i_tool_tag: Tag,
            i_base_tag: Tag
    ) -> List:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub MountDevice(Product iDevice,
                | CATBSTR iToolProfileName,
                | CATSafeArrayVariant iMountOffset,
                | boolean iToolMobility,
                | Tag iToolTag,
                | Tag iBaseTag)
                | 
                |     Mounts the device on to the Robot
                | 
                |     Parameters:
                | 
                |         iDevice
                |             The Device to mount 
                |         iToolProfileName
                |             Name of the Tool Profile 
                |         iMountOffset
                |             Offset required from the mount plate of the robot to base part of
                |             the device including position and orientation. If a Base Tag is selected then
                |             its the offset of MountPlate of the Robot to the Base Tag
                |             
                |         iToolMobility
                |             The Tool Mobility. 
                |         iToolTag
                |             The Tool Tag 
                |         iBaseTag
                |             The Base Tag 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The device is successfully mounted on the Robot.
                |         E_FAIL
                |             The device could not be mounted to the robot.
                | 
                |         Example:
                |             The following example mounts a device to a robot.
                | 
                |                Dim objMountManager As MountManager
                |                Dim Device As Product
                |                ...
                |                Dim ToolMobility As Boolean
                |                ToolMobility = TRUE   
                |                Dim TCPMatrix(5) As List
                |                TCPMatrix(0)=0
                |                TCPMatrix(1)=0
                |                TCPMatrix(2)=0
                |                TCPMatrix(3)=0
                |                TCPMatrix(4)=0
                |                TCPMatrix(5)=0
                |                Dim ToolProfileName As String
                |                ToolProfileName = "Tool.1"
                |                Dim BaseTag as Tag
                |                Dim ToolTag as Tag
                |                ...
                |                objMountManager.MountDevice
                |                object,name2,TCPMatrix,ModifyRef,ToolTag,Nothing

        :param Product i_device:
        :param str i_tool_profile_name:
        :param tuple i_mount_offset:
        :param bool i_tool_mobility:
        :param Tag i_tool_tag:
        :param Tag i_base_tag:
        :rtype: List
        """
        return List(
            self.mount_manager.MountDevice(
                i_device.com_object,
                i_tool_profile_name,
                i_mount_offset,
                i_tool_mobility,
                i_tool_tag.com_object,
                i_base_tag.com_object
            )
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'mount_device'
        # # vba_code = """
        # # Public Function mount_device(mount_manager)
        # #     Dim iDevice (2)
        # #     mount_manager.MountDevice iDevice
        # #     mount_device = iDevice
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def re_mount_device(self, i_device: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReMountDevice(Product iDevice)
                | 
                |     Remounts the device on the Robot
                | 
                |     Parameters:
                | 
                |         iDevice
                |             The device to be remount. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The device is successfully remounted on the Robot.
                |         E_FAIL
                |             The device could not be remounted.
                | 
                |         Example:
                |             The following example remounts a device on a
                |             robot.
                | 
                |                Dim objMountManager As MountManager
                |                Dim Device As Product
                |                ..
                |                objMountManager.ReMountDevice Device

        :param Product i_device:
        :rtype: None
        """
        return self.mount_manager.ReMountDevice(i_device.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 're_mount_device'
        # # vba_code = """
        # # Public Function re_mount_device(mount_manager)
        # #     Dim iDevice (2)
        # #     mount_manager.ReMountDevice iDevice
        # #     re_mount_device = iDevice
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def un_mount_device(self, i_device: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnMountDevice(Product iDevice)
                | 
                |     Unmounts the device from the Robot
                | 
                |     Parameters:
                | 
                |         iDevice
                |             The device to be unmount. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The device is successfully unmounted from the
                |             Robot.
                |         E_FAIL
                |             The device could not be unmounted.
                | 
                |         Example:
                |             The following example unmounts a device from a
                |             robot.
                | 
                |                Dim objMountManager As MountManager
                |                Dim Device As Product
                |                ..
                |                objMountManager.UnMountDevice Device

        :param Product i_device:
        :rtype: None
        """
        return self.mount_manager.UnMountDevice(i_device.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'un_mount_device'
        # # vba_code = """
        # # Public Function un_mount_device(mount_manager)
        # #     Dim iDevice (2)
        # #     mount_manager.UnMountDevice iDevice
        # #     un_mount_device = iDevice
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def un_set_device(self, i_device: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnSetDevice(Product iDevice)
                | 
                |     Unsets the device from the Robot
                | 
                |     Parameters:
                | 
                |         iDevice
                |             The device to be unset. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The device is successfully unset from the Robot.
                |         E_FAIL
                |             The device could not be unset.
                | 
                |         Example:
                |             The following example unsets a device from a
                |             robot.
                | 
                |                Dim objMountManager As MountManager
                |                Dim Device As Product
                |                ..
                |                objMountManager.UnSetDevice Device

        :param Product i_device:
        :rtype: None
        """
        return self.mount_manager.UnSetDevice(i_device.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'un_set_device'
        # # vba_code = """
        # # Public Function un_set_device(mount_manager)
        # #     Dim iDevice (2)
        # #     mount_manager.UnSetDevice iDevice
        # #     un_set_device = iDevice
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MountManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ArrBendableString(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrBendableString
                | 
                | The interface to access a CATIAArrBendableString
                | 
                | Using this prefered syntax will enable mkdoc to document your
                | class.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arr_bendable_string = com_object

    def get_num_of_segments(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumOfSegments() As long
                | 
                |     Returns the cumulative number of the straight/arc segments that make up the
                |     Bendable object.
                | 
                |     Example:
                |         This example shows how to number of segments of
                |         BendablePipe001.
                | 
                |          Dim NumOfBendSegments
                |          NumOfBendSegments = BendablePipe001.GetNumOfSegments

        :rtype: int
        """
        return self.arr_bendable_string.GetNumOfSegments()

    def get_num_of_segments_local_axis(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumOfSegmentsLocalAxis() As long
                | 
                |     Returns the cumulative number of the straight/arc segments that make up the
                |     Bendable object.

        :rtype: int
        """
        return self.arr_bendable_string.GetNumOfSegmentsLocalAxis()

    def get_segment_data(self, i_index: int, o_segment_data: tuple) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSegmentData(long iIndex,
                | CATSafeArrayVariant oSegmentData)
                | 
                |     Returns the data of the segment (Point Indices, Slope angle, Rotation
                |     Angle).
                | 
                |     Example:
                |         This example shows how to retrieve segment #2 of
                |         BendablePipe001.
                | 
                |          Dim SegmentData(14) As double
                |          BendablePipe001.GetSegmentData(2, SegmentData)
                |          where the data is returned in the Array in the following
                |          format...
                |          SegmentData(0)  = Starting Point of Segment (X Coord)
                |          SegmentData(1)  = Starting Point of Segment (Y Coord)
                |          SegmentData(2)  = Starting Point of Segment (Z Coord)
                |          SegmentData(3)  = End Point of Segment (X Coord)
                |          SegmentData(4)  = End Point of Segment (Y Coord)
                |          SegmentData(5)  = End Point of Segment (Z Coord)
                |          SegmentData(6)  = Bend Point of Segment (X Coord) '//Valid only if SegmentData(9) > 0
                |          SegmentData(7)  = Bend Point of Segment (Y Coord) '//Valid only if SegmentData(9) > 0
                |          SegmentData(8)  = Bend Point of Segment (Z Coord) '//Valid only if SegmentData(9) > 0
                |          SegmentData(9)  = Bend Radius at Bend Point '//Valid only if SegmentData(9) > 0
                |          SegmentData(10) = Bend Angle at Bend Point  '//Valid only if SegmentData(9) > 0
                |          SegmentData(11) = Rotation Angle of Segment
                |          SegmentData(12) = Slope Angle of Segment
                |          SegmentData(13) = Length of linear Segment
                |          SegmentData(14) = Length of Arc Segment '//Valid only if SegmentData(9) > 0

        :param int i_index:
        :param tuple o_segment_data:
        :rtype: float
        """
        return self.arr_bendable_string.GetSegmentData(i_index, o_segment_data)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_segment_data'
        # # vba_code = """
        # # Public Function get_segment_data(arr_bendable_string)
        # #     Dim iIndex (2)
        # #     arr_bendable_string.GetSegmentData iIndex
        # #     get_segment_data = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def instance_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func InstanceName() As CATBSTR
                | 
                |     Returns the Bendable's Instance Name.
                | 
                |     Example:
                |         This example shows how to retrieve the Bendable Instance Name of
                |         BendablePipe001.
                | 
                |          Dim _BendInstanceName
                |          _BendInstanceName = BendablePipe001.InstanceName

        :rtype: str
        """
        return self.arr_bendable_string.InstanceName()

    def __repr__(self):
        return f'ArrBendableString(name="{ self.name }")'
